import React from 'react';
import { Form, Input, Modal } from 'antd';

/**
 * All values that the modal window can show.
 */
export interface SubTagModalValues {
    name?: string;
    description?: string;
}

/**
 * Creates a modal window that works with properties of a sub tag.
 * @param props Contains arguments of the modal window.
 * @returns The modal window.
 */
function SubTagModal(props: {
    title: string; // Title of the modal
    submitText: string; // Text of submit button
    onCancel: () => void; // Method called when the modal is closed without submit
    onSubmit: (val: SubTagModalValues) => void; // Method called when the modal is submitted
    defaultValues?: SubTagModalValues; // Default values of a form that contains properties of the sub tag.
}) {
    /**
     * Initialize default values if they were not set in props.
     */
    let values: SubTagModalValues;

    if (props.defaultValues) {
        values = {
            name: props.defaultValues.name ?? '',
            description: props.defaultValues.description ?? '',
        };
    } else {
        values = {
            name: '',
            description: '',
        };
    }

    /**
     * The form.
     */
    const [form] = Form.useForm();

    /**
     * Handles cancelling of the model window.
     */
    const handleCancel = () => {
        props.onCancel();
    };

    /**
     * Handles submitting of the model window.
     * @param values Form values.
     */
    const handleOk = (values: any) => {
        props.onSubmit({
            name: values.name,
            description: values.description,
        });
    };

    return (
        <Modal
            title={props.title}
            visible={true}
            okText={props.submitText}
            cancelText="Zrušit"
            maskClosable={false}
            onCancel={handleCancel}
            onOk={() => {
                // Custom form validation when the modal is submitted.
                // Validates form and if all fields are valid it calls handleOk method.
                form.validateFields()
                    .then((values) => {
                        form.resetFields();
                        handleOk(values);
                    })
                    .catch((info) => {
                        console.log('Validate Failed:', info);
                    });
            }}
        >
            <Form form={form} labelCol={{ span: 4 }} initialValues={values}>
                <Form.Item
                    label="Název"
                    name="name"
                    rules={[{ required: true, message: 'Prosím zadejte název' }]}
                >
                    <Input />
                </Form.Item>
                <Form.Item label="Popis" name="description">
                    <Input.TextArea />
                </Form.Item>
            </Form>
        </Modal>
    );
}

export default SubTagModal;
